@@ -1,14 +1,16 @@
 package Yukki::Types;
 BEGIN {
-  $Yukki::Types::VERSION = '0.110830';
+  $Yukki::Types::VERSION = '0.110840';
 }
 use Moose;
 
 use MooseX::Types -declare => [ qw(
-    LoginName AccessLevel
+    LoginName AccessLevel NavigationLinks
+    BreadcrumbLinks
 ) ];
 
-use MooseX::Types::Moose qw( Str );
+use MooseX::Types::Moose qw( Str Int ArrayRef Maybe );
+use MooseX::Types::Structured qw( Dict );
 
 # ABSTRACT: standard types for use in Yukki
 
@@ -21,6 +23,25 @@ subtype LoginName,
 
 enum AccessLevel, qw( read write none );
 
+
+subtype NavigationLinks,
+    as ArrayRef[
+        Dict[
+            label => Str,
+            href  => Str,
+            sort  => Maybe[Int],
+        ],
+    ];
+
+
+subtype BreadcrumbLinks,
+    as ArrayRef[
+        Dict[
+            label => Str,
+            href  => Str,
+        ],
+    ];
+
 1;
 
 __END__
@@ -32,7 +53,7 @@ Yukki::Types - standard types for use in Yukki
 
 =head1 VERSION
 
-version 0.110830
+version 0.110840
 
 =head1 SYNOPSIS
 
@@ -59,6 +80,25 @@ This is a valid access level. This includes any of the following values:
   write
   none
 
+=head2 NavigationLinks
+
+THis is an array of hashes formatted like:
+
+  {
+      label => 'Label',
+      href  => '/link/to/somewhere',
+      sort  => 40,
+  }
+
+=head2 BreadcrumbLinks
+
+THis is an array of hashes formatted like:
+
+  {
+      label => 'Label',
+      href  => '/link/to/somewhere',
+  }
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
