@@ -1,6 +1,6 @@
 package Yukki::Web;
 BEGIN {
-  $Yukki::Web::VERSION = '0.110830';
+  $Yukki::Web::VERSION = '0.110840';
 }
 use Moose;
 
@@ -10,7 +10,9 @@ use Yukki::Error;
 use Yukki::Web::Context;
 use Yukki::Web::Router;
 
+use CHI;
 use HTTP::Throwable::Factory qw( http_throw http_exception );
+use Plack::Session::Store::Cache;
 use Scalar::Util qw( blessed );
 use Try::Tiny;
 
@@ -131,6 +133,18 @@ sub dispatch {
     return $response;
 }
 
+
+sub session_middleware {
+    my $self = shift;
+
+    # TODO Make this configurable
+    return ('Session', 
+        store => Plack::Session::Store::Cache->new(
+            cache => CHI->new(driver => 'FastMmap'),
+        ),
+    );
+}
+
 1;
 
 __END__
@@ -142,7 +156,7 @@ Yukki::Web - the Yukki web server
 
 =head1 VERSION
 
-version 0.110830
+version 0.110840
 
 =head1 DESCRIPTION
 
@@ -182,6 +196,12 @@ This is a PSGI application in a method call. Given a L<PSGI> environment, maps
 that to the appropriate controller and fires it. Whether successful or failure,
 it returns a PSGI response.
 
+=head2 session_middleware
+
+  enable $app->session_middleware;
+
+Returns the setup for the PSGI session middleware.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
